---
date: 2024-02-29
authors: [matt]
description: >
  Apply constraints on attributes of your design with assertions
categories:
  - Release
links:
---

# Be assertive 💪

![Equation solver](/assets/images/equation-preview.gif)

## Check yo'self before you wreck yo'... design

![Assertion Checks](/assets/images/assertion-checks-2.png)

atopile has your back when it comes to ensuring your design is correct. With the new assertion feature, you can apply constraints on attributes of your design.

- Make sure voltage inputs on ICs are withing operational ranges
- Avoid exceeding power limits on FETs
- Check temperature sensors function over their entire operating range

Think of this as unit tests for your electronics! 🤩


## Think in specs 🧠, let the computer find the components

atopile can find suitable component values for you, to configure your design in terms you want to think about.

Tell your filters what you want their cut-off to be, and let atopile find the right resistor and capacitor values for you.

Use code to spec what voltage you want your regulator to output, and let atopile find the resistors that meet spec for you!
